@@ -1,15 +1,16 @@
+from jina import __version__ as jina_version
 from jina.logging import JinaLogger
 from fastapi import status, APIRouter
 
-from config import openapitags_config, hypercorn_config
-
+from jinad.config import server_config
 
 logger = JinaLogger(context='👻 JINAD')
 common_router = APIRouter()
 
+
 @common_router.on_event('startup')
 async def startup():
-    logger.success(f'Hypercorn + FastAPI running on {hypercorn_config.HOST}:{hypercorn_config.PORT}')
+    logger.success(f'Uvicorn + FastAPI running on {server_config.HOST}:{server_config.PORT}')
     logger.success('Welcome to Jina daemon - the remote manager for jina!')
 
 
@@ -20,8 +21,10 @@ async def startup():
 )
 async def _status():
     """
-    Used to check if the api is running (returns 200)
+    Used to check if the api is running (returns 200 & jina version)
     """
+    # TODO(Deepankar): should we add versions of executors?
     return {
-        'status_code': status.HTTP_200_OK
+        'status_code': status.HTTP_200_OK,
+        'jina_version': jina_version
     }
