@@ -1,6 +1,6 @@
 from typing import Dict
 
-from .custom import build_pydantic_model
+from jinad.models.custom import build_pydantic_model
 
 PodModel = build_pydantic_model(model_name='PodModel',
                                 module='pod')
